/**************************************************************************/
/* Do File to create dataset for personality and entrepreneurship project */
/* We will combine 1995 and 2004 MIDUS data, and merge in 2004 data from  */
/* MIDUS Cognitive supplemental survey                                    */
/**************************************************************************/


clear
clear matrix

**** CHANGE THIS TO YOUR LOCAL DIRECTORY
cd "~/Dropbox/WORK/Personality/PERSONALITY_FINAL/REPLICATION/1_STATA" 

set mem 1g 
set more 1 
capture log close 
set logtype text 
set scheme s2mono 

* Primary data is from 2004 MIDUS 
* Set up 2004 data 

use DATASETS/_RAW/sedata04, clear 
sort m2id

* Get and rename identifiers, etc.
rename m2id id
rename m2famnum fam_no
rename b1status completion_status04

* Get gender and age
gen male04 = b1prsex==1
rename b1page_m age04


preserve
clear

use DATASETS/_RAW/sedata95, clear 

keep M2ID ZYGCAT
rename M2ID id
gen mono = (ZYGCAT==1)
gen diz = (ZYGCAT==2|ZYGCAT==3)
sort id
save DATASETS/temp04md, replace 
clear

restore

sort id 
merge id using DATASETS/temp04md
drop _merge
sort fam_no
by fam_no: egen np=count(fam_no) 
gen siblings=(samplmaj==1 & np>=2|samplmaj==2 & np>=2) 
sort fam_no 
by fam_no: egen age_max=max(age04) 
replace age04=age_max if mono==1|diz==1 
gen agesq04=(age04^2)/10 

* Get family variables
gen married04 = (b1pb19==1)
gen numkids04 = b1pc2

* Get working status 
rename b1pb3a working04

gen se04 = (b1pbwork == 2) 
gen pe04 = (b1pbwork == 1 | b1pbwork == 3 | b1pbwork == 4) 
gen retired04 = (b1pbwork == 5) 

* Get occupation variables
gen doctor04 = (b1pocc == 84) 
gen lawyer04 = (b1pocc == 178) 

* Get education variables
gen lths04=(b1pb1==1|b1pb1==2|b1pb1==3|b1pb1==4|b1pb1==97) 
gen hs04=(b1pb1==5) 
gen scoll04=(b1pb1==6|b1pb1==7|b1pb1==8) 
gen cgrad04=(b1pb1==9) 
gen pgrad04=(b1pb1==10|b1pb1==11|b1pb1==12) 

gen educ04 = 6 if b1pb1==1 
replace educ04 = 8  if b1pb1 == 2 
replace educ04 = 11 if b1pb1 == 3 | b1pb1 == 4
replace educ04 = 12 if b1pb1 == 5
replace educ04 = 14 if b1pb1 == 6 
replace educ04 = 15 if b1pb1 == 7 
replace educ04 = 14 if b1pb1== 8 
replace educ04 = 16 if b1pb1 == 9 
replace educ04 = 17 if b1pb1 == 10 
replace educ04 = 18 if b1pb1 == 11 | b1pb1 == 12 

* Fix earnings 
* Use imputed earnings first 
* For individuals earning over 200K, use midpoints of income categories 
gen earn04 = b1srinc2 
replace earn04 = 225000 if b1sg8a == 42 
replace earn04 = 275000 if b1sg8a == 43 
replace earn04 = 350000 if b1sg8a == 44 
replace earn04 = 450000 if b1sg8a == 45 
replace earn04 = 750000 if b1sg8a == 46 
replace earn04 = 1000000 if b1sg8a == 47 
replace earn04 = . if earn04 == 9999998 


* Create an earnings measure where everyone earns at least 1 dollar for use in logs 
gen earn104 = earn04 
replace earn104 = 1 if earn104 == 0 & (pe04 == 1 | se04 == 1) 
gen learn104 = ln(earn104) 

* Get personality variables
rename b1sopen O2
replace O2=. if O2==8
rename b1scons1 C21
replace C21=. if C21==8
rename b1scons2 C22
replace C22=. if C22==8
rename b1sextra E2
replace E2=. if E2==8
rename b1sagree A2
replace A2=. if A2==8
rename b1sneuro N2
replace N2=. if N2==8

* Get other psych variables 
gen selfd04 = b1sdirec  
replace selfd04 = . if selfd04 == 8
gen live404 = b1stoday
replace live404 = . if live404 == 8
gen forsight04 = b1sforsg
replace forsight04 = . if forsight04 == 8

* Get spousal variables 
* Create eduation variables for spouse 
gen splths04 = 0 
replace splths04 = 1 if b1pb33 == 1 | b1pb33 == 2 | b1pb33 == 3 | b1pb33 == 4 
gen sphs04 = 0 
replace sphs04 = 1 if b1pb33 == 5 
gen spscoll04 = 0 
replace spscoll04 = 1 if b1pb33 == 6 | b1pb33 == 7 | b1pb33 == 8 
gen spcgrad04 = 0 
replace spcgrad04 = 1 if b1pb33 == 9 
gen sppgrad_04 = 0 
replace sppgrad_04 = 1 if b1pb33 == 10 | b1pb33 == 11 | b1pb33 == 12 
gen spdkeduc04 = 0 
replace spdkeduc04 = 1 if b1pb33 == 97 

gen speduc04 = 6 if b1pb33==1 
replace speduc04 = 8 if b1pb33 == 2 
replace speduc04 = 11 if b1pb33 == 3 | b1pb33 == 4
replace speduc04 = 12 if b1pb33 == 5
replace speduc04 = 14 if b1pb33 == 6 
replace speduc04 = 15 if b1pb33 == 7 
replace speduc04 = 14 if b1pb33 == 8 
replace speduc04 = 16 if b1pb33 == 9 
replace speduc04 = 17 if b1pb33 == 10 
replace speduc04 = 18 if b1pb33 == 11 | b1pb33 == 12 

* Create labor supply variables for spouse
gen spse04 = 0 
replace spse04 = 1 if b1pb34b == 1 
gen sppe04 = 0 
replace sppe04 = 1 if b1pb34a == 1 & spse04 == 0 



* Get assets 
gen assets04=b1sg24a
replace assets04=. if assets04>100000000
gen assets104 = assets04+1
gen lassets104 = log(assets04)

keep 	id fam_no O2 C21 C22 E2 A2 N2 ///
		age04 agesq04 married04 numkids04 ///
		lths04 hs04 scoll04 cgrad04 pgrad04 educ04 se04 pe04 retired04 working04 earn04 earn104 learn104 ///
		doctor04 lawyer04 ///
        completion_status04 ///
        sp* ///
        selfd04 live404 forsight04 ///
		assets104 lassets104
                  

drop if earn04==0 & pe04==1				  
				  
sort id 

summ 

save DATASETS/temp04, replace 

clear 

















use DATASETS/_RAW/sedata95, clear

* Get and rename identifiers, etc.
rename M2ID id
rename M2FAMNUM fam_no
rename A1STATUS completion_status95

* Get gender and age
gen male95 = A1PRSEX==1
rename A1PAGE_M2 age95
gen agesq95=(age95^2)/10 


* Get family variables
gen married95 = (A1PB17==1)
gen numkids95= A1PB35 + A1PB37 if A1PB35<=5 & A1PB37<=5 
replace numkids95=A1PB35 if numkids95==. & A1PB35<=5 

* Get working status 
rename A1PB3A working95

gen se95 = (A1PB3B == 1) 
gen pe95 = (working95 == 1 | A1PB3C == 1 | A1PB3D == 1) 
gen retired_95 = (A1PB3E == 1)  
gen working_95 = (working95 == 1) 


* Get occupation variables
gen doctor95 = (A1PIND == 84) 
gen lawyer95 = (A1PIND == 178) 

* Get education variables
gen lths95=(A1PB1==1|A1PB1==2|A1PB1==3|A1PB1==4|A1PB1==97) 
gen hs95=(A1PB1==5) 
gen scoll95=(A1PB1==6|A1PB1==7|A1PB1==8) 
gen cgrad95=(A1PB1==9) 
gen pgrad95=(A1PB1==10|A1PB1==11|A1PB1==12) 

gen educ95 = 6 if A1PB1==1 
replace educ95 = 8 if A1PB1 == 2 
replace educ95 = 11 if A1PB1 == 3 | A1PB1 == 4
replace educ95 = 12 if A1PB1 == 5
replace educ95 = 14 if A1PB1 == 6 
replace educ95 = 15 if A1PB1 == 7 
replace educ95 = 14 if A1PB1 == 8 
replace educ95 = 16 if A1PB1 == 9 
replace educ95 = 17 if A1PB1 == 10 
replace educ95 = 18 if A1PB1 == 11 | A1PB1 == 12 

* Fix earnings 
* Use imputed earnings first 

gen earn95 = A1SJ8M 
replace earn95 = . if A1SJ8M == 999999 

* Create an earnings measure where everyone earns at least 1 dollar for use in logs 
gen earn195 = earn95 
replace earn195 = 1 if earn195 == 0 & (pe95 == 1 | se95 == 1) 
gen learn195 = ln(earn195) 

* Get personality variables
rename A1SOPEN O1
replace O1=. if O1==9

rename A1SCONS C1
replace C1=. if C1==9

rename A1SEXTRA E1
replace E1=. if E1==9

rename A1SAGREE A1
replace A1=. if A1==9

rename A1SNEURO N1
replace N1=. if N1==9

* Get other psych variables 
gen selfd95 = A1SDIREC
replace selfd95 = . if selfd95 == 8
gen live495 = A1STODAY 
replace live495 = . if live495 == 8
gen forsight95 = A1SFORSG
replace forsight95 = . if forsight95 == 8

* Get spousal variables 
* Create eduation variables for spouse 

* Get spousal variables 
gen splths95 = 0 
replace splths95 = 1 if A1PB27 == 1 | A1PB27 == 2 | A1PB27 == 3 | A1PB27 == 4 
gen sphs95 = 0 
replace sphs95 = 1 if A1PB27 == 5 
gen spscoll95 = 0 
replace spscoll95 = 1 if A1PB27 == 6 | A1PB27 == 7 | A1PB27 == 8 
gen spcgrad95 = 0 
replace spcgrad95 = 1 if A1PB27 == 9 
gen sppgrad95 = 0 
replace sppgrad95 = 1 if A1PB27 == 10 | A1PB27 == 11 | A1PB27 == 12 
gen spdkeduc95 = 0 
replace spdkeduc95 = 1 if A1PB27 == 97 

* Create years of education variable for spouse 
gen speduc95 = 6 if A1PB27==1 
replace speduc95 = 8 if A1PB27 == 2 
replace speduc95 = 11 if A1PB27 == 3 | A1PB27 == 4
replace speduc95 = 12 if A1PB27 == 5
replace speduc95 = 14 if A1PB27 == 6 
replace speduc95 = 15 if A1PB27 == 7 
replace speduc95 = 14 if A1PB27 == 8 
replace speduc95 = 16 if A1PB27 == 9 
replace speduc95 = 17 if A1PB27 == 10 
replace speduc95 = 18 if A1PB27 == 11 | A1PB27 == 12 

* Create labor supply variables for spouse
gen spse95 = 0 
replace spse95 = 1 if A1PB28B == 1 
gen sppe95 = 0 
replace sppe95 = 1 if A1PB28A == 1 & spse95 == 0 
gen spemploy95=(spse95==1 | sppe95==1)


* Get parental background variables 
gen fathernone = 0 
replace fathernone = 1 if A1PC2 == 99 
gen fatherlths = 0 
replace fatherlths = 1 if A1PC2 == 1 | A1PC2 == 2 | A1PC2 == 3 | A1PC2 == 4
gen fatherhs = 0 
replace fatherhs = 1 if A1PC2 == 5 
gen fatherscoll = 0
replace fatherscoll = 1 if A1PC2 == 6 | A1PC2 == 7 | A1PC2 == 8 
gen fathercgrad = 0 
replace fathercgrad = 1 if A1PC2 == 9
gen fatherpgrad = 0 
replace fatherpgrad = 1 if A1PC2 == 10 | A1PC2 == 11 | A1PC2 == 12 
gen fathereducdk = 0 
replace fathereducdk = 1 if A1PC2 == 97 


* Create years of education variable for father 
gen fathereduc = 6 if A1PC2==1 
replace fathereduc = 8 if A1PC2 == 2 
replace fathereduc = 11 if A1PC2 == 3 | A1PC2 == 4
replace fathereduc = 12 if A1PC2 == 5
replace fathereduc = 14 if A1PC2 == 6 
replace fathereduc = 15 if A1PC2 == 7 
replace fathereduc = 14 if A1PC2 == 8 
replace fathereduc = 16 if A1PC2 == 9 
replace fathereduc = 17 if A1PC2 == 10 
replace fathereduc = 18 if A1PC2 == 11 | A1PC2 == 12 
replace fathereduc = 0 if fathereduc == . 

gen mothernone = 0 
replace mothernone = 1 if A1PC8 == 99 
gen motherlths = 0 
replace motherlths = 1 if A1PC8  == 1 | A1PC8 == 2 | A1PC8 == 3 | A1PC8 == 4
gen motherhs = 0 
replace motherhs = 1 if A1PC8 == 5 
gen motherscoll = 0
replace motherscoll = 1 if A1PC8 == 6 | A1PC8 == 7 | A1PC8 == 8 
gen mothercgrad = 0 
replace mothercgrad = 1 if A1PC8 == 9
gen motherpgrad = 0 
replace motherpgrad = 1 if A1PC8 == 10 | A1PC8 == 11 | A1PC8 == 12 
gen mothereducdk = 0 
replace mothereducdk = 1 if A1PC8 == 97 

* Create years of education variable for mother 
gen mothereduc = 6 if A1PC8==1 
replace mothereduc = 8 if A1PC8 == 2 
replace mothereduc = 11 if A1PC8 == 3 | A1PC8 == 4
replace mothereduc = 12 if A1PC8 == 5
replace mothereduc = 14 if A1PC8 == 6 
replace mothereduc = 15 if A1PC8 == 7 
replace mothereduc = 14 if A1PC8 == 8 
replace mothereduc = 16 if A1PC8 == 9 
replace mothereduc = 17 if A1PC8 == 10 
replace mothereduc = 18 if A1PC8 == 11 | A1PC8 == 12 
replace mothereduc = 0 if mothereduc == . 

* Create parent work variables
rename A1PC3 fatherwrk
gen fatherse = (A1PC6_2==2)

rename A1PC9 motherwrk
gen motherse = (A1PC13_2==2)

gen mothernowork = 0 
replace mothernowork = 1 if motherwrk == 5 

* Get Assets
gen assets95 = A1SASSET
replace assets95 = . if assets95 == 99999 
replace assets95=100*assets95
gen assets195=assets95
replace assets195=1 if assets95==0
gen lassets195=ln(assets195)
gen assets95sq=(assets95 * assets95)/100

keep 	id fam_no O1 C1 E1 A1 N1 ///
		age95 agesq95 male95 married95 numkids95 ///
		lths95 hs95 scoll95 cgrad95 pgrad95 educ95 se95 pe95 working95 earn95 earn195 learn195 ///
		doctor95 lawyer95 ///
        completion_status95 ///
		father* mother* ///
        sp* ///
        assets95 assets195 assets95sq lassets195 ///
        selfd95 live495 forsight95 ///


                  

summ 

sort id 
save DATASETS/temp95, replace 

merge id using DATASETS/temp04 

tab _merge 

gen merge9504 = _merge 

drop _merge 

sort id 

save DATASETS/temp9504, replace 



clear 



* Now get 2004 intelligence data 


use DATASETS/_RAW/cognition.dta

gen id = M2ID 

gen fluid = B3TCOMP 
replace fluid = . if fluid == 8 | fluid == 9 

gen episodic  = B3TEM 
replace episodic = . if episodic == 8 

gen exec = B3TEF 
replace exec = . if exec == exec == 8 

keep id fluid episodic exec 

sort id 

summ 

save DATASETS/tempcog, replace 

clear 

use DATASETS/temp9504 

merge id using DATASETS/tempcog 

tab _merge 


gen merge9504cog = _merge 

drop _merge 

sort id 

save DATASETS/personality, replace 

erase DATASETS/tempcog.dta 
erase DATASETS/temp95.dta 
erase DATASETS/temp04.dta 
erase DATASETS/temp9504.dta 
erase DATASETS/temp04md.dta 





 
 
/* Data set to compare 896  1995 */

clear
clear matrix
use Datasets/personality 


rename C21 C2
rename male95 male

keep    id male ///
		se04 pe04 earn104 learn104 ///
		se95 pe95 earn195 learn195 ///
		assets95 assets195 lassets195 assets95sq assets104 lassets104 ///
		fluid episodic exec  ///
		A2 E2 N2 C2 O2  ///
		A1 E1 N1 C1 O1  ///		
		hs04 scoll04 cgrad04 educ04 ///
		hs95 scoll95 cgrad95 educ95 ///
		age04 agesq04 age95 agesq95 ///
		married04 married95 numkids04 numkids95 ///
		live495 live404 ///	
		speduc04 spse95 sppe95 spemploy95 fathereduc mothereduc fatherse motherse    ///
		completion_status04 working04 working95

*replace numkids04=5 if numkids04>5 & numkids04!=.

order    id male ///
		se04 pe04 earn104 learn104 ///
		se95 pe95 earn195 learn195 ///
		assets95 assets195 lassets195 assets95sq assets104 lassets104 ///
		fluid episodic exec  ///
		A2 E2 N2 C2 O2  ///
		A1 E1 N1 C1 O1  ///		
		hs04 scoll04 cgrad04 educ04 ///
		hs95 scoll95 cgrad95 educ95 ///
		age04 agesq04 age95 agesq95 ///
		married04 married95 numkids04 numkids95 ///
		live495 live404 ///	
		speduc04 spse95 sppe95 spemploy95 fathereduc mothereduc fatherse motherse    ///
		completion_status04 working04 working95
 
replace speduc04=0 if speduc04==. & married04==0

sort id
summarize id
scalar minimum=r(min)
replace id=id-minimum+1

lab var se04 				"Self-employment"
lab var pe04				"Paid employment"
lab var earn104				"Earnings"
lab var learn104			"Log earnings"
lab var se95				"Self-employment (1995)"
lab var pe95				"Paid employment (1995)"
lab var earn195				"Earnings (1995)"
lab var learn195			"Log earnings (1995)"
lab var assets95			"Assets (1995)"
lab var assets195			"Assets (1995) no zeros"
lab var lassets195			"Log assets (1995)"
lab var assets95sq			"Assets-squared (1995)"
lab var exec 				"Executive function"
lab var episodic			"Episodic memory"
lab var	O1					"Openness (1995)"
lab var	C1					"Conscientiousness (1995)"
lab var	E1					"Extraversion (1995)"
lab var	A1					"Agreeableness (1995)"
lab var	N1					"Neuroticism (1995)"
lab var	O2					"Openness (2004)"
lab var	C2					"Conscientiousness (2004)"
lab var	E2					"Extraversion (2004)"
lab var	A2					"Agreeableness (2004)"
lab var	N2					"Neuroticism (2004)"
lab var hs04				"High school"
lab var scoll04				"Some college"
lab var cgrad04				"College grad"	
lab var educ04				"Years of education"
lab var hs95				"High school (1995)"
lab var scoll95				"Some college (1995)"
lab var cgrad95				"College grad (1995)"	
lab var educ95				"Years of educ. (1995)"
lab var fluid				"Cognition"
lab var age04				"Age"
lab var agesq04				"Age-squared"
lab var age95				"Age (1995)"
lab var agesq95				"Age-squared (1995)"
lab var married04			"Married"
lab var married95			"Married (1995)"
lab var numkids95			"Number of kids (1995)"
lab var numkids04			"Number of kids"
lab var live404				"Live for today"
lab var live495				"Live for today (1995)"
lab var speduc04			"Spouse education"
lab var spse95				"Spouse self-employed (1995)"
lab var sppe95				"Spouse paid employed (1995)"
lab var spemploy95			"Spouse employed (1995)"
lab var fathereduc			"Father education"
lab var mothereduc			"Mother education"
lab var fatherse			"Father self-employed"
lab var motherse			"Mother self-employed"

count
sum

tab completion_status04

preserve
* Get to 896 as usual
count
keep if male==1 
drop if age04>65 
keep if completion_status04==2 
keep if working04==1|se04==1 
drop if O1==. | C1==. |E1==. |A1==. |N1==. 
drop if O2==. | C2==. |E2==. |A2==. |N2==. 
drop if married04==. | numkids04==. | spemploy95==. | speduc04==.
drop if lassets195==.
drop if fluid==. 
drop if learn195==.
drop if se95==.
drop if fathereduc==. | mothereduc==.
drop if fatherse==. | motherse==.
drop if episodic==. | exec==.

count

restore



*CREATE 1995 Sample
gen status04 = 0 if completion_status04 !=2
replace status04=1 if completion_status04==2
tab status

keep if male==1 
drop if age04>65 & status==1

keep if (working04==1|se04==1) | status04==0

drop if lassets195==.


drop if (O1==. | C1==. |E1==. |A1==. |N1==.) 
drop if (O2==. | C2==. |E2==. |A2==. |N2==.) & status04==1 
drop if (married04==. | numkids04==. | spemploy95==. | speduc04==.) & status04==1
drop if fluid==. & status04==1
drop if learn195==.
drop if (fathereduc==. | mothereduc==.) & status04==1
drop if (fatherse==. | motherse==.) & status04==1
drop if (episodic==. | exec==.) & status04==1
drop if se95==.

count
tab status

drop if age95>65
drop if (working95!=1 & se95!=1) & status04==0

count
tab status

save Datasets/personalityEXTRA, replace











clear
clear matrix
use Datasets/personality 

keep if male==1 
drop if age04>65 
keep if completion_status04==2 
keep if working04==1|se04==1 
rename C21 C2
rename male95 male

keep    id ///
		se04 pe04 earn104 learn104 ///
		se95 pe95 earn195 learn195 ///
		assets95 assets195 lassets195 assets95sq assets104 lassets104 ///
		fluid episodic exec  ///
		A2 E2 N2 C2 O2  ///
		A1 E1 N1 C1 O1  ///
		hs04 scoll04 cgrad04 educ04 ///
		hs95 scoll95 cgrad95 educ95 ///
		age04 agesq04 age95 agesq95 ///
		married04 married95 numkids04 numkids95 ///
		live495 live404 ///	
		speduc04 spse95 sppe95 spemploy95 fathereduc mothereduc fatherse motherse   

*replace num_kids_04=5 if num_kids_04>5 & num_kids_04!=.

order    id ///
		se04 pe04 earn104 learn104 ///
		se95 pe95 earn195 learn195 ///
		assets95 assets195 lassets195 assets95sq assets104 lassets104 ///
		fluid episodic exec  ///
		A2 E2 N2 C2 O2  ///
		A1 E1 N1 C1 O1  ///
		hs04 scoll04 cgrad04 educ04 ///
		hs95 scoll95 cgrad95 educ95 ///
		age04 agesq04 age95 agesq95 ///
		married04 married95 numkids04 numkids95 ///
		live495 live404 ///	
		speduc04 spse95 sppe95 spemploy95 fathereduc mothereduc fatherse motherse     

replace speduc04=0 if speduc04==. & married04==0

sort id
summarize id
scalar minimum=r(min)
replace id=id-minimum+1

lab var se04 				"Self-employment"
lab var pe04				"Paid employment"
lab var earn104				"Earnings"
lab var learn104			"Log earnings"
lab var se95				"Self-employment (1995)"
lab var pe95				"Paid employment (1995)"
lab var earn195				"Earnings (1995)"
lab var learn195			"Log earnings (1995)"
lab var assets95			"Assets (1995)"
lab var assets195			"Assets (1995) no zeros"
lab var lassets195			"Log assets (1995)"
lab var assets95sq			"Assets-squared (1995)"
lab var exec 				"Executive function"
lab var episodic			"Episodic memory"
lab var	O1					"Openness (1995)"
lab var	C1					"Conscientiousness (1995)"
lab var	E1					"Extraversion (1995)"
lab var	A1					"Agreeableness (1995)"
lab var	N1					"Neuroticism (1995)"
lab var	O2					"Openness (2004)"
lab var	C2					"Conscientiousness (2004)"
lab var	E2					"Extraversion (2004)"
lab var	A2					"Agreeableness (2004)"
lab var	N2					"Neuroticism (2004)"
lab var hs04				"High school"
lab var scoll04				"Some college"
lab var cgrad04				"College grad"	
lab var educ04				"Years of education"
lab var hs95				"High school (1995)"
lab var scoll95				"Some college (1995)"
lab var cgrad95				"College grad (1995)"	
lab var educ95				"Years of educ. (1995)"
lab var fluid				"Cognition"
lab var age04				"Age"
lab var agesq04				"Age-squared"
lab var age95				"Age (1995)"
lab var agesq95				"Age-squared (1995)"
lab var married04			"Married"
lab var married95			"Married (1995)"
lab var numkids95			"Number of kids (1995)"
lab var numkids04			"Number of kids"
lab var live404				"Live for today"
lab var live495				"Live for today (1995)"
lab var speduc04			"Spouse education"
lab var spse95				"Spouse self-employed (1995)"
lab var sppe95				"Spouse paid employed (1995)"
lab var spemploy95			"Spouse employed (1995)"
lab var fathereduc			"Father education"
lab var mothereduc			"Mother education"
lab var fatherse			"Father self-employed"
lab var motherse			"Mother self-employed"

save DATASETS/personalityFULL, replace 

count
sum

drop if se04==. | learn104==. | educ04==. | age04==.

drop if O1==. | C1==. |E1==. |A1==. |N1==. 
drop if O2==. | C2==. |E2==. |A2==. |N2==. 
drop if married04==. | numkids04==. | spemploy95==. | speduc04==.
drop if lassets195==.
drop if fluid==. 
drop if learn195==.
drop if se95==.
drop if fathereduc==. | mothereduc==.
drop if fatherse==. | motherse==.
drop if episodic==. | exec==.


save DATASETS/personality, replace 

keep id se04 pe04 learn104 se95 pe95 learn195 assets95 assets195 lassets195 assets95sq fluid episodic exec A2 E2 N2 C2 O2 A1 E1 N1 C1 O1 hs04 scoll04 cgrad04 educ04 ///
hs95 scoll95 cgrad95 educ95 age04 agesq04 age95 agesq95 married04 married95 numkids04 speduc04 spse95 sppe95 spemploy95 assets104 lassets104

order id se04 pe04 learn104 se95 pe95 learn195 assets95 assets195 lassets195 assets95sq fluid episodic exec A2 E2 N2 C2 O2 A1 E1 N1 C1 O1 hs04 scoll04 cgrad04 educ04 ///
hs95 scoll95 cgrad95 educ95 age04 agesq04 age95 agesq95 married04 married95 numkids04 speduc04 spse95 sppe95 spemploy95 assets104 lassets104

replace assets104 = 9999999999 if assets104==.
replace lassets104 = 9999999999 if lassets104==.

cd ..
cd ..

export delimited using "REPLICATION/2_MATLAB/DATASETS/personality_ML.csv", replace novarnames
