/****************************************************************************/
/* Do File to generate reduced-form results								  	*/	
/* for personality and entrepreneurship project								*/
/* Reults (Tables and Figures) in Paper								    	*/
/* Results "Available from Others Upon Request" that are mentioned in paper	*/
/****************************************************************************/


clear
clear matrix
cd "~/Dropbox/WORK/PERSONALITY/PERSONALITY_FINAL/REPLICATION/1_STATA" 

set mem 1g 
set more 1 
capture log close 
set logtype text 
set scheme lean1 

global	figures "FIGURES"
global	tables 	"TABLES"





/****************************************************************************/
/* Do File to generate reduced-form results								  	*/	
/* for personality and entrepreneurship project								*/
/* Reults (Tables) in Paper								    	*/
/****************************************************************************/





/* Table 1: Summary Statistics*/





clear
use DATASETS/personality, replace 
count

ttest earn104	, by(pe04)
centile earn104
centile earn104 if pe04==1
centile earn104 if pe04==0
di 58500-57500
median(earn104)	, by(pe04)
ttest assets95	, by(pe04)
ttest hs04		, by(pe04)
ttest scoll04	, by(pe04)
ttest cgrad04	, by(pe04)
ttest age04		, by(pe04)
ttest numkids04	, by(pe04)
ttest speduc04	if married04==1, by(pe04)
ttest spemploy95 if married04==1, by(pe04)
ttest fluid		, by(pe04)
ttest O1		, by(pe04)
ttest O2		, by(pe04)
ttest C1		, by(pe04)
ttest C2		, by(pe04)
ttest E1		, by(pe04)
ttest E2		, by(pe04)
ttest A1		, by(pe04)
ttest A2		, by(pe04)
ttest N1		, by(pe04)
ttest N2		, by(pe04)





/* Table 3: Sector Earnings and Sector Choice */





clear
use DATASETS/personality, replace 
count
sum

reg learn104 		O2 C2 E2 A2 N2 fluid educ04 age04  married04 if se04==1
est2vec Earningsprobit, ///
e(N) vars(O2 C2 E2 A2 N2 fluid educ04 age04 married04 numkids04 speduc04 spemploy95) ///
replace name(col1)

reg learn104 		O2 C2 E2 A2 N2 fluid educ04 age04  married04 if se04==0 
est2vec Earningsprobit, addto(Earningsprobit) name(col2)

probit se04			O2 C2 E2 A2 N2 fluid educ04 age04 married04 numkids04 speduc04 spemploy95 
est2vec Earningsprobit, addto(Earningsprobit) name(col3)

est2rowlbl   O2 C2 E2 A2 N2 fluid educ04 age04  married04 numkids04 speduc04 spemploy95, ///
saving addto(Earningsprobit) /// 
path(tables) replace

est2texOWO Earningsprobit, replace preserve  digits(2) fancy label ///
 collabels([1] [2] [3][4] [5] [6]) dots leadzero ///
 negative  longnames notabular path($tables)
clear





/* Appendix Table S1: Summary Statistics - Full Sample */





clear
use DATASETS/personalityFULL, replace 
count

tab se04

ttest earn104	, by(pe04)
centile earn104
centile earn104 if pe04==1
centile earn104 if pe04==0
di 57500-57500
median(earn104)	, by(pe04)
ttest assets95	, by(pe04)
ttest hs04		, by(pe04)
ttest scoll04	, by(pe04)
ttest cgrad04	, by(pe04)
ttest age04		, by(pe04)
ttest numkids04	, by(pe04)
ttest speduc04	if married04==1, by(pe04)
ttest spemploy95 if married04==1, by(pe04)
ttest fluid		, by(pe04)
ttest O1		, by(pe04)
ttest O2		, by(pe04)
ttest C1		, by(pe04)
ttest C2		, by(pe04)
ttest E1		, by(pe04)
ttest E2		, by(pe04)
ttest A1		, by(pe04)
ttest A2		, by(pe04)
ttest N1		, by(pe04)
ttest N2		, by(pe04)





/* Appendix Table S2: Reduced Form Results: Sector Choice (Analytic Sample) */





clear
use DATASETS/personality, replace 
count
sum

probit se04 O2 C2 E2 A2 N2 fluid 
probit se04 O2 C2 E2 A2 N2 fluid age04 
probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 
probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04
probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04
probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc
probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc fatherse motherse
probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc fatherse motherse live404

probit se04 O2 C2 E2 A2 N2 fluid
est2vec tablechoice, ///
e(N) vars(O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc fatherse motherse live404) ///
replace name(col1)

probit se04 O2 C2 E2 A2 N2 fluid age04 
est2vec tablechoice, addto(tablechoice) name(col2)

probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 
est2vec tablechoice, addto(tablechoice) name(col3)

probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04
est2vec tablechoice, addto(tablechoice) name(col4)

probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04
est2vec tablechoice, addto(tablechoice) name(col5)

probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc
est2vec tablechoice, addto(tablechoice) name(col6)

probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc fatherse motherse
est2vec tablechoice, addto(tablechoice) name(col7)

probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc fatherse motherse live404
est2vec tablechoice, addto(tablechoice) name(col8)

est2rowlbl   O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc fatherse motherse live404, ///
saving addto(tablechoice) /// 
path(tables) replace

est2texOWO tablechoice, replace preserve mark(starb) digits(2) fancy label ///
 collabels([1] [2] [3] [4] [5] [6] [7]) dots leadzero ///
 negative  longnames notabular path($tables)

clear





/* Appendix Table S3: Reduced Form Results: Sector Choice (Larger Sample) */





clear
use DATASETS/personalityFULL, replace 
count
sum

probit se04 O2 C2 E2 A2 N2 
probit se04 O2 C2 E2 A2 N2 fluid
probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 
probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04
probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04
probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc
probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc fatherse motherse
probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc fatherse motherse live404
probit se04 O2 C2 E2 A2 N2 fluid O1 C1 E1 A1 N1 age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc fatherse motherse live404



probit se04 O2 C2 E2 A2 N2
est2vec tablechoicefull, ///
e(N) vars(O2 C2 E2 A2 N2 fluid  age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc fatherse motherse live404) ///
replace name(col1)

probit se04 O2 C2 E2 A2 N2 fluid age04 
est2vec tablechoicefull, addto(tablechoicefull) name(col2)

probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 
est2vec tablechoicefull, addto(tablechoicefull) name(col3)

probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04
est2vec tablechoicefull, addto(tablechoicefull) name(col4)

probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04
est2vec tablechoicefull, addto(tablechoicefull) name(col5)

probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc
est2vec tablechoicefull, addto(tablechoicefull) name(col6)

probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc fatherse motherse
est2vec tablechoicefull, addto(tablechoicefull) name(col7)

probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc fatherse motherse live404
est2vec tablechoicefull, addto(tablechoicefull) name(col8)

est2rowlbl   O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc fatherse motherse live404, ///
saving addto(tablechoicefull) /// 
path(tables) replace

est2texOWO tablechoicefull, replace preserve mark(starb) digits(2) fancy label ///
 collabels([1] [2] [3] [4] [5] [6] [7] [8]) dots leadzero ///
 negative  longnames notabular path($tables)

clear





/* Appendix Table S4: Trait Stability */





clear
use DATASETS/personality, replace 
count
sum

reg O2 O1 age04 se95 lassets195 learn195
est2vec stabilitycombined, ///
e(N r2) vars(O1 C1 E1 A1 N1 age04 se95 lassets195 learn195) ///
replace name(col1)

reg C2 C1 age04 se95 lassets195 learn195
est2vec stabilitycombined, addto(stabilitycombined) name(col2)

reg E2 E1 age04 se95 lassets195 learn195
est2vec stabilitycombined, addto(stabilitycombined) name(col3)

reg A2 A1 age04 se95 lassets195 learn195
est2vec stabilitycombined, addto(stabilitycombined) name(col4)

reg N2 N1 age04 se95 lassets195 learn195
est2vec stabilitycombined, addto(stabilitycombined) name(col5)

est2rowlbl   N1 age04 se95 lassets195 learn195, ///
saving addto(stabilitycombined) /// 
path(tables) replace

est2texOWO stabilitycombined, replace preserve mark(starb) digits(2) fancy label ///
 collabels([1] [2] [3] [4] [5]) dots leadzero ///
 negative  longnames notabular path($tables)

 
 
 

 /* Appendix Table S5: Openness and 2004 Entry for 1995 Self Employed */

 
 
 
 
clear
use DATASETS/personality, replace 
count
sum

probit se04 O2 C2 E2 A2 N2 fluid if se95==1  
est2vec reentry, ///
vars(O2 C2 E2 A2 N2 fluid learn195 educ04 age04 married04 numkids04 speduc04 spemploy95) ///
replace name(col1)

probit se04 O2 C2 E2 A2 N2 fluid learn195 if se95==1
est2vec reentry, addto(reentry) name(col2)

probit se04 O2 C2 E2 A2 N2 fluid learn195 educ04 age04 married04 if se95==1 
est2vec reentry, addto(reentry) name(col3)

probit se04 O2 C2 E2 A2 N2 fluid learn195 educ04 age04 married04 numkids04 speduc04 spemploy95 if se95==1 
est2vec reentry, addto(reentry) name(col4)

est2rowlbl O2 C2 E2 A2 N2 fluid learn195 educ04 age04 married04 numkids04 speduc04 spemploy95,   ///
saving addto(reentry) /// 
path(Tables) replace

est2texOWO reentry, replace preserve mark(starb) digits(2) fancy label   ///
 collabels([1] [2] [3] [4] [5]) dots leadzero ///
 negative  longnames controlrows notabular path($tables)





/* Appendix Table S6: Earnings for Individuals Self-Employed in 1995 and 2004 */





clear
use DATASETS/personality, replace 
count
sum

reg learn104 learn195 if se95==1 & se04==1
est2vec earnings9504, ///
vars(learn195  O2 C2 E2 A2 N2 fluid educ04 age04 married04) ///
replace name(col1)

reg learn104 learn195 O2 C2 E2 A2 N2 fluid if se95==1 & se04==1
est2vec earnings9504, addto(earnings9504) name(col2)

reg learn104 learn195 O2 C2 E2 A2 N2 fluid educ04 age04 married04 if se95==1 & se04==1
est2vec earnings9504, addto(earnings9504) name(col3)

est2rowlbl learn195 fluid O2 C2 E2 A2 N2 educ04 age04 married04,   ///
saving addto(earnings9504) /// 
path(Tables) replace

est2texOWO earnings9504, replace preserve mark(starb) digits(2) fancy label   ///
 collabels([1] [2] [3]) dots leadzero ///
 negative  longnames controlrows notabular path($tables)

reg learn104 O2 C2 E2 A2 N2 fluid if se95==1 & se04==1
reg learn104 O2 C2 E2 A2 N2 fluid educ04 age04 married04 if se95==1 & se04==1

 
 
 
/****************************************************************************/
/* Do File to generate reduced-form results								  	*/	
/* for personality and entrepreneurship project								*/
/* Reults (Figures) in Paper								    			*/
/****************************************************************************/





/* Figures 1-2: Assets and Entry; Assets and SE Earnings */





clear
use DATASETS/personality, replace 
count
sum

twoway lpolyci se04 assets195 , ciplot(rline) alpattern(dash)  ///
	|| scatter se04 assets195 , msymbol(o) 	///
	legend(pos(6) col(1))  yline(0 .25 .5 .75 1)	 xlabel(0(200000)1010000) ysize(6)
	graph export $figures/choiceassets.pdf, replace

twoway lpolyci earn104 assets195 if se04==1, ciplot(rline) alpattern(dash)  ///
	|| scatter earn104 assets195 if se04==1, msymbol(o) 	///
	legend(pos(6) col(1))  yline(0 .25 .5 .75 1) xlabel(0(200000)1010000) ysize(6)
	graph export $figures/earnassets.pdf, replace





/* Figures 3-4: Assets and Entry; Assets and SE Earnings */




 
clear
use DATASETS/personality, replace 
count
sum

reg learn104 		O2 C2 E2 A2 N2 fluid educ04 age04  married04 if se04==1
predict yse, xb
reg learn104 		O2 C2 E2 A2 N2 fluid educ04 age04  married04 if pe04==1
predict ype, xb
gen diff=yse-ype
sum diff 
label var diff "Relative log SE Earnings"

twoway lpolyci se04 O2, ciplot(rline) alpattern(dash) ///
	|| scatter se04 O2, msymbol(o) 	///
	legend(pos(6) col(1))  yline(0 .25 .5 .75 1) ysize(6)
	graph export $figures/opennesschoice.pdf, replace

twoway lpolyci diff O2, ciplot(rline) alpattern(dash) /// 
|| scatter diff O2, msymbol(o) ///
||, legend(pos(6) col(1)) yline( -1 0 1) ysize(6)
	graph export $figures/opennesslogreturns.pdf, replace 
 
 

 
 
/****************************************************************************/
/* Do File to generate reduced-form results								  	*/	
/* for personality and entrepreneurship project								*/
/* Results Available Upon Request, etc. (Tables, Figures, SVALS)			*/
/****************************************************************************/





/* Just in Footnote: Sample Selection */





clear
use DATASETS/personalityEXTRA, replace 
count
sum

tab status

ttest earn195	, by(status)
ttest assets95	, by(status)
ttest se95		, by(status)

ttest hs95		, by(status)
ttest scoll95	, by(status)
ttest cgrad95	, by(status)

ttest age95		, by(status)
ttest married95	, by(status)
ttest numkids95	, by(status)
ttest spemploy95, by(status)

ttest O1		, by(status)
ttest C1		, by(status)
ttest E1		, by(status)
ttest A1		, by(status)
ttest N1		, by(status)


reg lassets195 learn195 age95 educ95 married95 numkids95 spemploy95 O1 C1 E1 A1 N1
predict res, residuals
ttest res, by(status)

sum assets195 if status==0, de
sum assets195 if status==1, de





/* RAUR: Interacted Model */





clear
use DATASETS/personality, replace 
count
sum

reg learn104 		O2 C2 E2 A2 N2 fluid educ04 age04  married04 if se04==1
reg learn104 		O2 C2 E2 A2 N2 fluid educ04 age04  married04 if pe04==1

gen seO2=O2*se04
gen seC2=C2*se04
gen seE2=E2*se04
gen seA2=A2*se04
gen seN2=N2*se04
gen seeduc04 = educ04*se04 
gen seage04 = age04*se04 
gen semarried04 = married04*se04
gen sefluid = fluid*se04
gen sespeduc = speduc04*se04
gen senumkids = numkids04*se04
gen sespemploy = spemploy*se04

reg learn104 		O2 C2 E2 A2 N2 ///
					seO2 seC2 seE2 seA2 seN2 

reg learn104 		O2 C2 E2 A2 N2 fluid ///
					seO2 seC2 seE2 seA2 seN2 sefluid 

reg learn104 		O2 C2 E2 A2 N2 fluid educ04 age04  ///
					seO2 seC2 seE2 seA2 seN2 sefluid seeduc04 seage04
					
reg learn104 		O2 C2 E2 A2 N2 fluid educ04 age04 married04 ///
					seO2 seC2 seE2 seA2 seN2 sefluid seeduc04 seage04 semarried04
					
reg learn104 		O2 C2 E2 A2 N2 fluid educ04 age04 married04 spemploy ///
					seO2 seC2 seE2 seA2 seN2 sefluid seeduc04 seage04 semarried04 sespemploy 

reg learn104 		O2 C2 E2 A2 N2 fluid educ04 age04 married04 speduc numkids04 spemploy ///
					seO2 seC2 seE2 seA2 seN2 sefluid seeduc04 seage04 semarried04 sespeduc senumkids sespemploy 
					
drop if earn104>=1000000 & se04==1

reg learn104 		O2 C2 E2 A2 N2 ///
					seO2 seC2 seE2 seA2 seN2 

reg learn104 		O2 C2 E2 A2 N2 fluid ///
					seO2 seC2 seE2 seA2 seN2 sefluid 

reg learn104 		O2 C2 E2 A2 N2 fluid educ04 age04  ///
					seO2 seC2 seE2 seA2 seN2 sefluid seeduc04 seage04  

reg learn104 		O2 C2 E2 A2 N2 fluid educ04 age04 married04 ///
					seO2 seC2 seE2 seA2 seN2 sefluid seeduc04 seage04 semarried04

reg learn104 		O2 C2 E2 A2 N2 fluid educ04 age04 married04 speduc numkids04 spemploy ///
					seO2 seC2 seE2 seA2 seN2 sefluid seeduc04 seage04 semarried04 sespeduc senumkids sespemploy 

reg learn104 		O2 C2 E2 A2 N2 fluid educ04 age04 married04 spemploy ///
					seO2 seC2 seE2 seA2 seN2 sefluid seeduc04 seage04 semarried04 sespemploy 

reg learn104 		O2 C2 E2 A2 N2 fluid educ04 age04 married04 speduc numkids04 spemploy ///
					seO2 seC2 seE2 seA2 seN2 sefluid seeduc04 seage04 semarried04 sespeduc senumkids sespemploy 




					
/* RAUR: Only PE in 1995 */





clear
use DATASETS/personality, replace 
count
sum

probit se04 O2 C2 E2 A2 N2 fluid if se95==0
probit se04 O2 C2 E2 A2 N2 fluid age04 if se95==0
probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 if se95==0
probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 if se95==0
probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04 if se95==0
probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc if se95==0
probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc fatherse motherse if se95==0
probit se04 O2 C2 E2 A2 N2 fluid age04  educ04 married04 numkids04 spemploy95 speduc04 fathereduc mothereduc fatherse motherse live404 if se95==0

tab se04 if se95==0




/* Structual Probit without very high or low earnings, no age sq. */
/* Note: fathereduc, mothereduc needed; otherwise collinear */




use DATASETS/personality, replace 

count
sum

reg learn104 		O2 C2 E2 A2 N2 fluid educ04 age04 married04 fathereduc mothereduc if se04==1
predict yse, xb
reg learn104 		O2 C2 E2 A2 N2 fluid educ04 age04 married04 fathereduc mothereduc if pe04==1
predict ype, xb
gen diff=yse-ype
sum diff 
gen yyse=exp(yse)
gen yype=exp(ype)
gen expdiff=yyse-yype
lab var expdiff "Expected Difference: Self minus Paid"
hist expdiff, bin(100) fraction
probit se04   			O2 C2 E2 A2 N2 fluid educ04 age04 married04 numkids04 speduc04 spemploy95 
probit se04 diff 		O2 C2 E2 A2 N2 fluid educ04 age04 married04 numkids04 speduc04 spemploy95 





/* Structual Probit without very high or low earnings, no age sq. */
/* Note: fathereduc, mothereduc needed; otherwise collinear */
/* Note: larger O2 when we trim obsverations */




clear
use DATASETS/personality, replace 
count
sum
drop if earn104<10000 | earn104>200000

reg learn104 		O1 C1 E1 A1 N1 fluid educ04 age04 fathereduc mothereduc if se04==1
predict yse, xb
reg learn104 		O1 C1 E1 A1 N1 fluid educ04 age04 fathereduc mothereduc if pe04==1
predict ype, xb
gen diff=yse-ype
sum diff 
gen yyse=exp(yse)
gen yype=exp(ype)
gen expdiff=yyse-yype
lab var expdiff "Expected Difference: Self minus Paid"
hist expdiff, bin(100) fraction
probit se04   			O1 C1 E1 A1 N1 fluid educ04 age04 married04 numkids04 speduc04 spemploy95 
probit se04 diff 		O1 C1 E1 A1 N1 fluid educ04 age04 married04 numkids04 speduc04 spemploy95 





clear
use DATASETS/personality, replace 
count
sum
drop if earn104<10000 | earn104>200000

reg learn104 		O2 C2 E2 A2 N2 fluid educ04 age04 fathereduc mothereduc if se04==1
predict yse, xb
reg learn104 		O2 C2 E2 A2 N2 fluid educ04 age04 fathereduc mothereduc if pe04==1
predict ype, xb
gen diff=yse-ype
sum diff 
gen yyse=exp(yse)
gen yype=exp(ype)
gen expdiff=yyse-yype
lab var expdiff "Expected Difference: Self minus Paid"
hist expdiff, bin(100) fraction
probit se04   			O2 C2 E2 A2 N2 fluid educ04 age04 married04 numkids04 speduc04 spemploy95 
probit se04 diff 		O2 C2 E2 A2 N2 fluid educ04 age04 married04 numkids04 speduc04 spemploy95 




/* Structual Probit without very high or low earnings, no age sq. */
/* Note: fathereduc, mothereduc needed; otherwise collinear */
/* Note: EVEN larger O2 when we add assets to PE pay */


clear
use DATASETS/personality, replace 
count
sum

reg learn104 		lassets195 O2 C2 E2 A2 N2 fluid educ04 age04 if se04==1
predict yse, xb
reg learn104 		lassets195 O2 C2 E2 A2 N2 fluid educ04 age04 if pe04==1
predict ype, xb
gen diff=yse-ype
sum diff 
gen yyse=exp(yse)
gen yype=exp(ype)
gen expdiff=yyse-yype
lab var expdiff "Expected Difference: Self minus Paid"
hist expdiff, bin(100) fraction
probit se04   			O2 C2 E2 A2 N2 fluid educ04 age04 married04 numkids04 speduc04 spemploy95 
probit se04 diff 		O2 C2 E2 A2 N2 fluid educ04 age04 married04 numkids04 speduc04 spemploy95 


/* Assets */

clear
use DATASETS/personality, replace 
count
sum

replace assets104=. if assets104==9999999999
replace lassets104=. if lassets104==9999999999

reg lassets104 lassets195 
predict sigmaa, stdr
di sigmaa
drop sigmaa

reg lassets104 lassets195 if se95==0
reg lassets104 lassets195 if se95==1

reg lassets104 lassets195, nocon
predict sigmaa, stdr
di sigmaa
drop sigmaa

reg lassets104 lassets195 if lassets195<13 & lassets104<13 & lassets195>0 & lassets104>0, nocon 
predict sigmaa, stdr
di sigmaa
drop sigmaa

reg lassets104 lassets195 if se95==0, nocon
reg lassets104 lassets195 if se95==1, nocon


/* SVALS PE,SE earnings */



clear
use DATASETS/personality, replace 
count
sum

reg learn104 educ04 age04 married04 fluid if pe04==1
predict sigma1, stdr
di sigma1

reg learn104 lassets195 if se04==1
predict sigma2, stdr
di sigma2

reg learn104 educ04 age04 married04 fluid A2 E2 N2 C2 O2 if pe04==1
predict sigma3, stdr
di sigma3

drop sigma1 sigma2 sigma3 


/* SVALS PE,SE earnings */



clear
use DATASETS/personality, replace 
count
sum

*MODEL 0 STARTING VALUES
reg learn104 lassets195 educ04 age04 married04 fluid if se04==0
predict sigma1, stdr
di sigma1 

reg learn104 lassets195 if se04==1
predict sigma2, stdr
di sigma2

drop sigma1 sigma2

*MODEL 1 STARTING VALUES
reg learn104 lassets195 educ04 age04 married04 fluid A2 E2 N2 C2 O2 if se04==0
predict sigma1, stdr
di sigma1 

reg learn104 lassets195 educ04 age04 married04 fluid A2 E2 N2 C2 O2 if se04==1
predict sigma2, stdr
di sigma2

drop sigma1 sigma2





reg learn104 educ04 age04 married04 fluid if pe04==1
predict sigma1, stdr
di sigma1

reg learn104 lassets195 if se04==1
predict sigma2, stdr
di sigma2

reg learn104 educ04 age04 married04 fluid A2 E2 N2 C2 O2 if pe04==1
predict sigma3, stdr
di sigma3

/*
************ TRASH
************ TRASH
************ TRASH
************ TRASH
************ TRASH
************ TRASH
************ TRASH
************ TRASH
************ TRASH
************ TRASH
************ TRASH
